
import peasy.*;
PeasyCam cam;

int startYear = 6;
int endYear = 70;

Table table;
int numRows, numColumns;

ArrayList<Book> books = new ArrayList<Book>();

void setup() {
  size(1300, 1300, P3D);
  cam = new PeasyCam(this, 100);
  //fullScreen(P3D);

  //Added on Jan 30th by Rodger Luo
  float  cameraZ = (height/2.0) / tan(PI*60.0/360.0);
  perspective(PI/3.0, width/height, 0.001, cameraZ*10.0); //set near clip to 0.001 to go inside data
  //Finished adding 

  table = loadTable("DIY.csv", "header");
  numRows = table.getRowCount();
  println("Rows: " + numRows);

  for (int i=0; i<numRows; i++) {
    String elements = table.getString(i, 2);
    String time = table.getString(i, 3);
    String date = table.getString(i, 4);
    int count = table.getInt(i, 1);
    String title = table.getString(i, 0);
    books.add(new Book(elements, time, date, count, title));
  }

  //println(books.size());
}

void draw() {
  background(10);

  for (int i=0; i<9952; i++) {
    float yearAxis = map (dateParser(books.get(i).date), 0, 3650, -50, 50);
    float timeAxis = map (timeParser(books.get(i).time), 300, 1200, -100, 100);
    float deweyAxis = map(log(books.get(i).count), 0, log(155), -120, 250);
    color c = elementDetermine(books.get(i).element);
    pushMatrix();
    translate(yearAxis, timeAxis, deweyAxis);
    strokeWeight(5);
    stroke(c);
    point(10, 20);
    popMatrix();
  }

  drawLabels();  

  fill(250, 10, 10, 20);
  noStroke();
  box(80);
}

void drawLabels() {
  fill(100);
  textSize(60);
  pushMatrix();
  textAlign(LEFT, TOP);
  translate(-50, 50, 50);
  scale(0.1);
  text("2006", 0, 0, 0);
  popMatrix();

  pushMatrix();
  textAlign(CENTER, TOP);
  translate(50, 50, 50);
  scale(0.1);
  text("2015", 0, 0, 0);
  popMatrix();

  pushMatrix();
  textAlign(RIGHT, TOP);
  translate(-50, -50, 50);
  scale(0.1);
  text("2:00PM", 0, 0, 0);
  popMatrix();

  pushMatrix();
  textAlign(RIGHT, BOTTOM);
  translate(-50, 50, 50);
  scale(0.1);
  text("7:00AM", 0, 0, 0);
  popMatrix();

  pushMatrix();
  textAlign(TOP, CENTER);
  translate(25, -50, 50);
  scale(0.1);
  text("Checkouts 155", 0, 0, 0);
  popMatrix();

  pushMatrix();
  textAlign(LEFT, CENTER);
  translate(50, 50, -50);
  scale(0.1);
  text("Check Outs 0", 0, 0, 0);
  popMatrix();

  cam.beginHUD();
  textSize(20);
  fill(255);
  text("DIY : 2006-2017", 15, 30, 50);
  textSize(15);
  text("Frequency of media checked out from SPL that involves the title DIY ", 15, 50, 50);
  text("acbk = red ", 15, 70, 50);
  text("acdvd = green ", 15, 90, 50);
  text("accd = yellow ", 15, 110, 50);
  text("jcbk = turquoise", 15, 130, 50);
  
  cam.endHUD();
}